@@ -41,7 +41,7 @@ struct TestWindow : public QWidget {
         mMainWidget = new QTextEdit();
         QVBoxLayout *layout = new QVBoxLayout(this);
         layout->setSpacing(0);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->addWidget(mMainWidget);
         layout->addWidget(mContainer);
     }
