@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,14 +24,14 @@
 #include "richtextcomposeremailquotehighlighter.h"
 #include "nestedlisthelper_p.h"
 #include "richtextexternalcomposer.h"
+#include "grantleebuilder/plaintextmarkupbuilder.h"
+#include "grantleebuilder/markupdirector.h"
 #include <QTextBlock>
 #include <QTextLayout>
 #include <QClipboard>
 
 #include "richtextcomposeremailquotedecorator.h"
 
-#include <grantlee/plaintextmarkupbuilder.h>
-
 #include <KActionCollection>
 #include <QAction>
 #include <QFileInfo>
@@ -233,9 +233,9 @@ void RichTextComposer::forcePlainTextMarkup(bool force)
 void RichTextComposer::insertPlainTextImplementation()
 {
     if (d->forcePlainTextMarkup) {
-        Grantlee::PlainTextMarkupBuilder *pb = new Grantlee::PlainTextMarkupBuilder();
+        KPIMTextEdit::PlainTextMarkupBuilder *pb = new KPIMTextEdit::PlainTextMarkupBuilder();
 
-        Grantlee::MarkupDirector *pmd = new Grantlee::MarkupDirector(pb);
+        KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
         pmd->processDocument(document());
         const QString plainText = pb->getResult();
         document()->setPlainText(plainText);
