@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,6 +27,7 @@
 #include <QLabel>
 #include <QMenu>
 #include <QHBoxLayout>
+#include <QRegularExpression>
 
 using namespace KPIMTextEdit;
 
@@ -36,8 +37,9 @@ TextReplaceWidget::TextReplaceWidget(QWidget *parent)
     QHBoxLayout *lay = new QHBoxLayout(this);
     QLabel *label = new QLabel(i18nc("Replace text", "Replace:"), this);
     lay->addWidget(label);
-    const int marg = lay->margin();
-    lay->setContentsMargins(marg, 0, marg, 0);
+    const int marg1 = lay->contentsMargins().left();
+    const int marg2 = lay->contentsMargins().right();
+    lay->setContentsMargins(marg1, 0, marg2, 0);
 
     mReplace = new QLineEdit(this);
     mReplace->setClearButtonEnabled(true);
@@ -71,8 +73,9 @@ TextFindWidget::TextFindWidget(QWidget *parent)
     : QWidget(parent)
 {
     QHBoxLayout *lay = new QHBoxLayout(this);
-    const int marg = lay->margin();
-    lay->setContentsMargins(marg, 0, marg, 0);
+    const int marg1 = lay->contentsMargins().left();
+    const int marg2 = lay->contentsMargins().right();
+    lay->setContentsMargins(marg1, 0, marg2, 0);
     QLabel *label = new QLabel(i18nc("Find text", "F&ind:"), this);
     lay->addWidget(label);
 
@@ -171,6 +174,7 @@ QString TextFindWidget::searchText() const
     return mSearch->text();
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
 QRegExp TextFindWidget::searchRegExp() const
 {
     QRegExp reg;
@@ -187,6 +191,22 @@ QRegExp TextFindWidget::searchRegExp() const
     return reg;
 }
 
+#else
+QRegularExpression TextFindWidget::searchRegExp() const
+{
+    QRegularExpression reg;
+    if (!mCaseSensitiveAct->isChecked()) {
+        reg.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
+    }
+    QString searchTextString = mSearch->text();
+    if (mWholeWordAct->isChecked()) {
+        searchTextString = QStringLiteral("\\b") + searchTextString + QStringLiteral("\\b");
+    }
+    reg.setPattern(searchTextString);
+    return reg;
+}
+
+#endif
 QTextDocument::FindFlags TextFindWidget::searchOptions() const
 {
     QTextDocument::FindFlags opt = nullptr;
